@@ -1,17 +1,17 @@
 ;(function(){
   var map = {
-  "commitId": "9987e42baec8a630e36c99b340aab6e9e020e35b",
+  "commitId": "884d8c6659eac9c8b3d40634e1c4c8bd2f63adcb",
   "branchName": "release",
-  "buildTime": "Fri, 17 Mar 2023 16:35:53 GMT",
-  "buildVersion": "5.1.318",
+  "buildTime": "Mon, 27 Mar 2023 06:16:04 GMT",
+  "buildVersion": "322",
   "css": [
     "@zoom/client-calendar/static/css/default~app.391672d7.css",
     "@zoom/client-calendar/static/css/vendors~app.f43a7829.css"
   ],
   "js": [
-    "@zoom/client-calendar/static/js/default~app.c93cb147.js",
+    "@zoom/client-calendar/static/js/default~app.3c7fd519.js",
     "@zoom/client-calendar/static/js/vendors~app.1f3ccfa0.js",
-    "@zoom/client-calendar/static/js/app.e0fcfa75.js"
+    "@zoom/client-calendar/static/js/app.dfb42586.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
