@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "63d32b0362058179d552cc9ebf734608e30524b3",
-  "branchName": "release-client-5.13.x",
-  "buildTime": "Fri, 24 Feb 2023 08:54:07 GMT",
-  "buildVersion": "5.1.210",
+  "commitId": "8488df62afddb95d5be0ecf3be2ae3c430ca5fa7",
+  "branchName": "release",
+  "buildTime": "Tue, 14 Mar 2023 08:46:40 GMT",
+  "buildVersion": "5.1.219",
   "css": [
     "@zoom/client-scheduler/static/css/chunk-vendors.af34567c.css",
     "@zoom/client-scheduler/static/css/index.0cf63661.css"
   ],
   "js": [
-    "@zoom/client-scheduler/static/js/chunk-vendors.2d23d481.js",
-    "@zoom/client-scheduler/static/js/index.9660f796.js"
+    "@zoom/client-scheduler/static/js/chunk-vendors.ca3385b0.js",
+    "@zoom/client-scheduler/static/js/index.742daf72.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
